@@ -4,7 +4,7 @@ from cliff.command import Command
 from enough import settings
 from enough.common.openstack import OpenStack
 from enough.common import dotenough
-from enough.cli import openstack
+from enough.common import options
 
 
 class Create(Command):
@@ -15,7 +15,7 @@ class Create(Command):
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument('volumes', nargs='*')
-        openstack.set_common_options(parser)
+        options.set_options(parser)
         return parser
 
     def take_action(self, parsed_args):
@@ -35,7 +35,7 @@ class Prune(Command):
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument('days', type=int, default=30)
-        openstack.set_common_options(parser)
+        options.set_options(parser)
         return parser
 
     def take_action(self, parsed_args):
