@@ -17,7 +17,7 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
     domain = f'enough.test'
     s = service.ServiceOpenStack(str(tmpdir), settings.SHARE_DIR, **{
         'driver': 'openstack',
-        'playbook': 'tests/enough/common/test_common_service/enough-playbook.yml',
+        'playbook': os.path.abspath('tests/enough/common/test_common_service/enough-playbook.yml'),
         'domain': domain,
         'name': 'essential',
     })
@@ -30,8 +30,21 @@ def test_openstack_create_or_update(tmpdir, openstack_name, requests_mock):
     assert r['fqdn'] == f'essential.{domain}'
 
 
-def test_service_from_host(tmpdir):
+def test_service_from_host():
     s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
-    assert s.service_from_host('bind-host') == 'essential'
+    assert s.service_from_host('icinga-host') in ('essential', 'openvpn', 'wekan')
     assert s.service_from_host('cloud-host') == 'cloud'
     assert s.service_from_host('unknown-host') is None
+
+
+def test_update_vpn_dependencies():
+    s = service.Service(settings.CONFIG_DIR, settings.SHARE_DIR)
+    assert s.hosts_with_internal_network(['bind-host']) == []
+    assert 'website-host' not in s.service2hosts['openvpn']
+    assert 'website-host' not in s.service2hosts['weblate']
+    s.ansible.set_inventories(['tests/enough/common/test_common_service/vpn_inventory'])
+    s.set_service2hosts()
+    assert 'website-host' in s.service2hosts['openvpn']
+    assert s.hosts_with_internal_network(['icinga-host']) == ['icinga-host']
+    s.update_vpn_dependencies()
+    assert 'website-host' in s.service2hosts['weblate']
