@@ -1,7 +1,7 @@
 import os
 import yaml
 
-from enough.common.dotenough import Hosts, DotEnough, DotEnoughOpenStack
+from enough.common.dotenough import Hosts, DotEnoughOpenStack
 
 
 #
@@ -12,12 +12,14 @@ def test_hosts_create_delete(tmpdir):
     h = Hosts(config_dir)
     host = 'HOST'
     ip = '1.2.3.4'
-    assert h.create_or_update(host, ip) is True
-    assert h.create_or_update(host, ip) is False
+    port = '22'
+    assert h.create_or_update(host, ip, port) is True
+    assert h.create_or_update(host, ip, port) is False
     assert os.path.exists(f'{config_dir}/inventory/hosts.yml')
     h = Hosts(config_dir)
-    assert h.create_or_update(host, ip) is False
+    assert h.create_or_update(host, ip, port) is False
     assert h.hosts[host]['ansible_host'] == ip
+    assert h.hosts[host]['ansible_port'] == port
 
     assert h.missings([host, 'MISSING']) == ['MISSING']
 
@@ -29,29 +31,6 @@ def test_hosts_create_delete(tmpdir):
 #
 # DotEnough
 #
-def test_remap():
-    p = '.enough/thing'
-    unchanged = '/foo/bar/'
-    expected = [f'{os.path.expanduser("~")}/{p}', unchanged]
-    assert DotEnough.remap([f'/home/user/{p}', unchanged]) == expected
-    expected = [f'--option={os.path.expanduser("~")}/{p}', unchanged]
-    assert DotEnough.remap([f'--option=/home/user/{p}', unchanged]) == expected
-
-
-def test_preserve_ownership(mocker, tmpdir):
-    #
-    # not running as root, do nothing
-    #
-    assert DotEnough.preserve_ownership() is False
-
-    #
-    # pretend to run as root and chown to self
-    #
-    mocker.patch('os.geteuid', return_value=0)
-    mocker.patch('os.path.expanduser', return_value=str(tmpdir))
-    assert DotEnough.preserve_ownership() is True
-
-
 def test_openstack_openrc2clouds(tmpdir):
 
     openrc_file = f'{tmpdir}/openrc.sh'
