@@ -155,6 +155,11 @@ def test_network(openstack_name):
     assert o.network_exists(openstack_name)
     assert o.subnet_exists(openstack_name)
 
+    dns_ip = '1.2.3.4'
+    o.subnet_update_dns(openstack_name, dns_ip)
+    r = o.o.subnet.show('--format=value', '-c', 'dns_nameservers', openstack_name)
+    assert r.strip() == dns_ip
+
 
 @pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
                     reason='skip integration test')
@@ -201,5 +206,5 @@ def test_openstack_replace_volume(openstack_name):
     o.o.volume.create('--size=1', other_volume)
     assert openstack_name in o.o.volume.list('--name', openstack_name)
     o.replace_volume(openstack_name, other_volume)
-    assert o.o.volume.list('--name', openstack_name).strip() == ''
-    assert other_volume in o.o.volume.list('--name', other_volume)
+    assert o.o.volume.list('--name', other_volume).strip() == ''
+    assert openstack_name in o.o.volume.list('--name', openstack_name)
